@@ -21,9 +21,12 @@ class get_player:
 		if name == None and uuid == None:
 			raise NoInputError
 
-		elif not name == None or not uuid == None:
+		if not name == None or not uuid == None:
+			
 			if uuid == None:
 				uuid = get_uuid(name)
+
+
 		response = requests.get(f"{HYPIXEL_API}/player?key={self.api}&uuid={uuid}")
 		json = response.json()
 
